*#----------------------------------------------------
* This estimation code is related to the paper:
*
* Andrzej Cieślik & Oleg Gurshev (2023) 
* Trade policies in central Asia after EAEU enlargement and 
* after Russian WTO accession: regionalism and integration into the world economy revisited,
* Eurasian Geography and Economics, DOI: 10.1080/15387216.2022.2162098
*
*
* If you use this code in your research, please site the paper.

*#----------------------------------------------------
* Use this if want unilateral results
drop if exporter == "Uzbekistan"
drop if exporter != "Uzbekistan" 

drop if exporter == "Tajikistan"
drop if exporter != "Tajikistan"

*------------------------------------
* Variable generation
drop if y == 0
gen Y = log(y)
gen P = log (P_imf_f_ratio_to_exports)
gen GDP_I = log(gdp_i)
gen GDP_J = log(gdp_j)
gen DIST = log(DIST)

*--------------------------------------------------------------------------------------
* Main result for Tajikistan data:
*(full bilateral trade data)
eststo clear

eststo: reg3 (eq1: y gdp_i gdp_j P_imf_f_ratio_to_exports M_EUEA) (eq2: y gdp_i gdp_j P_imf_f_ratio_to_exports M_SPECA) (eq3: y gdp_i gdp_j P_imf_f_ratio_to_exports M_CHINA) (eq4: y gdp_i gdp_j P_imf_f_ratio_to_exports M_IRAN) (eq5: y gdp_i gdp_j P_imf_f_ratio_to_exports M_TURKEY) (eq6: y gdp_i gdp_j P_imf_f_ratio_to_exports M_WTO) , exog(dist comcol colony contig)

esttab, se star(+ 0.10 ** 0.05 *** 0.01)

esttab using Tajikistan_main_result_with_WTO.rtf, se star(+ 0.10 ** 0.05 *** 0.01)

*Robustness
reg3 (eq1: y gdp_i gdp_j P_imf_f_ratio_to_exports M_EUEA) (eq2: y gdp_i gdp_j P_imf_f_ratio_to_exports M_SPECA) (eq3: y gdp_i gdp_j P_imf_f_ratio_to_exports M_CHINA) (eq4: y gdp_i gdp_j P_imf_f_ratio_to_exports M_IRAN) (eq5: y gdp_i gdp_j P_imf_f_ratio_to_exports M_TURKEY) (eq6: y gdp_i gdp_j P_imf_f_ratio_to_exports M_WTO) , exog(dist comcol colony contig) sure
*---------------------------------------------------------------------------------------
* Main result for Uzbekistan data:
*(full bilateral trade data)
eststo clear

eststo: reg3 (eq1: y gdp_i gdp_j P_imf_f_ratio_to_exports M_EUEA) (eq2: y  gdp_i gdp_j P_imf_f_ratio_to_exports M_SPECA) (eq3: y  gdp_i gdp_j  P_imf_f_ratio_to_exports M_CHINA) (eq4: y  gdp_i gdp_j P_imf_f_ratio_to_exports M_IRAN) (eq5: y  gdp_i gdp_j P_imf_f_ratio_to_exports M_TURKEY) (eq6: y  gdp_i gdp_j P_imf_f_ratio_to_exports M_WTO), exog(dist comcol colony contig comlag)

esttab, se star(+ 0.10 ** 0.05 *** 0.01)

esttab using Uzbekistan_main_result_with_WTO.rtf, se star(+ 0.10 ** 0.05 *** 0.01)

*Robustness
reg3 (eq1: y gdp_i gdp_j P_imf_f_ratio_to_exports M_EUEA) (eq2: y  gdp_i gdp_j P_imf_f_ratio_to_exports M_SPECA) (eq3: y  gdp_i gdp_j  P_imf_f_ratio_to_exports M_CHINA) (eq4: y  gdp_i gdp_j P_imf_f_ratio_to_exports M_IRAN) (eq5: y  gdp_i gdp_j P_imf_f_ratio_to_exports M_TURKEY) (eq6: y  gdp_i gdp_j P_imf_f_ratio_to_exports M_WTO), exog(dist comcol colony contig comlag) sure
*---------------------------------------------------------------------------------------






